diff --git a/ASLUAV/version.h b/ASLUAV/version.h
index 0349171..e338f4b 100644
--- a/ASLUAV/version.h
+++ b/ASLUAV/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Thu Jul 06 2017"
+#define MAVLINK_BUILD_DATE "Thu Jul 13 2017"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/ardupilotmega/version.h b/ardupilotmega/version.h
index 1eb2a74..9e8283a 100644
--- a/ardupilotmega/version.h
+++ b/ardupilotmega/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Thu Jul 06 2017"
+#define MAVLINK_BUILD_DATE "Thu Jul 13 2017"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/autoquad/version.h b/autoquad/version.h
index 3e39195..fac955c 100644
--- a/autoquad/version.h
+++ b/autoquad/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Thu Jul 06 2017"
+#define MAVLINK_BUILD_DATE "Thu Jul 13 2017"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/common/version.h b/common/version.h
index acc3d0e..92a09a4 100644
--- a/common/version.h
+++ b/common/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Thu Jul 06 2017"
+#define MAVLINK_BUILD_DATE "Thu Jul 13 2017"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/matrixpilot/version.h b/matrixpilot/version.h
index ba24fa2..856466c 100644
--- a/matrixpilot/version.h
+++ b/matrixpilot/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Thu Jul 06 2017"
+#define MAVLINK_BUILD_DATE "Thu Jul 13 2017"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/message_definitions/common.xml b/message_definitions/common.xml
index 2906cbb..199a861 100644
--- a/message_definitions/common.xml
+++ b/message_definitions/common.xml
@@ -4122,8 +4122,8 @@
WIP: Information about the status of a capture
Timestamp (milliseconds since system boot)
Camera ID (1 for first, 2 for second, etc.)
- Current status of image capturing (0: not running, 1: interval capture in progress)
- Current status of video capturing (0: not running, 1: capture in progress)
+ Current status of image capturing (0: idle, 1: capture in progress, 2: interval set but idle, 3: interval set and capture in progress)
+ Current status of video capturing (0: idle, 1: capture in progress)
Image capture interval in seconds
Time in milliseconds since recording started
Available storage capacity in MiB
diff --git a/minimal/version.h b/minimal/version.h
index feb13df..0be7f63 100644
--- a/minimal/version.h
+++ b/minimal/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Thu Jul 06 2017"
+#define MAVLINK_BUILD_DATE "Thu Jul 13 2017"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 9
diff --git a/slugs/version.h b/slugs/version.h
index 10075b3..3838c44 100644
--- a/slugs/version.h
+++ b/slugs/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Thu Jul 06 2017"
+#define MAVLINK_BUILD_DATE "Thu Jul 13 2017"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/standard/version.h b/standard/version.h
index c99dd56..3dd7c62 100644
--- a/standard/version.h
+++ b/standard/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Thu Jul 06 2017"
+#define MAVLINK_BUILD_DATE "Thu Jul 13 2017"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/test/version.h b/test/version.h
index 3182ba6..8538e28 100644
--- a/test/version.h
+++ b/test/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Thu Jul 06 2017"
+#define MAVLINK_BUILD_DATE "Thu Jul 13 2017"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 179
diff --git a/uAvionix/version.h b/uAvionix/version.h
index 7dd9da7..3c88481 100644
--- a/uAvionix/version.h
+++ b/uAvionix/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Thu Jul 06 2017"
+#define MAVLINK_BUILD_DATE "Thu Jul 13 2017"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/common/mavlink_msg_camera_capture_status.h b/common/mavlink_msg_camera_capture_status.h
index b010eb0..dd9d85f 100644
--- a/common/mavlink_msg_camera_capture_status.h
+++ b/common/mavlink_msg_camera_capture_status.h
@@ -10,8 +10,8 @@ typedef struct __mavlink_camera_capture_status_t {
uint32_t recording_time_ms; /*< Time in milliseconds since recording started*/
float available_capacity; /*< Available storage capacity in MiB*/
uint8_t camera_id; /*< Camera ID (1 for first, 2 for second, etc.)*/
- uint8_t image_status; /*< Current status of image capturing (0: not running, 1: interval capture in progress)*/
- uint8_t video_status; /*< Current status of video capturing (0: not running, 1: capture in progress)*/
+ uint8_t image_status; /*< Current status of image capturing (0: idle, 1: capture in progress, 2: interval set but idle, 3: interval set and capture in progress)*/
+ uint8_t video_status; /*< Current status of video capturing (0: idle, 1: capture in progress)*/
}) mavlink_camera_capture_status_t;
#define MAVLINK_MSG_ID_CAMERA_CAPTURE_STATUS_LEN 19
@@ -61,8 +61,8 @@ typedef struct __mavlink_camera_capture_status_t {
*
* @param time_boot_ms Timestamp (milliseconds since system boot)
* @param camera_id Camera ID (1 for first, 2 for second, etc.)
* @param image_status Current status of image capturing (0: not running, 1: interval capture in progress)
* @param video_status Current status of video capturing (0: not running, 1: capture in progress)
* @param image_interval Image capture interval in seconds
* @param recording_time_ms Time in milliseconds since recording started
* @param available_capacity Available storage capacity in MiB
@@ -107,8 +107,8 @@ static inline uint16_t mavlink_msg_camera_capture_status_pack(uint8_t system_id,
* @param msg The MAVLink message to compress the data into
* @param time_boot_ms Timestamp (milliseconds since system boot)
* @param camera_id Camera ID (1 for first, 2 for second, etc.)
* @param image_status Current status of image capturing (0: not running, 1: interval capture in progress)
* @param video_status Current status of video capturing (0: not running, 1: capture in progress)
* @param image_interval Image capture interval in seconds
* @param recording_time_ms Time in milliseconds since recording started
* @param available_capacity Available storage capacity in MiB
@@ -179,8 +179,8 @@ static inline uint16_t mavlink_msg_camera_capture_status_encode_chan(uint8_t sys
*
* @param time_boot_ms Timestamp (milliseconds since system boot)
* @param camera_id Camera ID (1 for first, 2 for second, etc.)
* @param image_status Current status of image capturing (0: not running, 1: interval capture in progress)
* @param video_status Current status of video capturing (0: not running, 1: capture in progress)
* @param image_interval Image capture interval in seconds
* @param recording_time_ms Time in milliseconds since recording started
* @param available_capacity Available storage capacity in MiB
@@ -292,7 +292,7 @@ static inline uint8_t mavlink_msg_camera_capture_status_get_camera_id(const mavl
/**
* @brief Get field image_status from camera_capture_status message
*
* @return Current status of image capturing (0: not running, 1: interval capture in progress)
*/
static inline uint8_t mavlink_msg_camera_capture_status_get_image_status(const mavlink_message_t* msg)
{
@@ -302,7 +302,7 @@ static inline uint8_t mavlink_msg_camera_capture_status_get_image_status(const m
/**
* @brief Get field video_status from camera_capture_status message
*
* @return Current status of video capturing (0: not running, 1: capture in progress)
*/
static inline uint8_t mavlink_msg_camera_capture_status_get_video_status(const mavlink_message_t* msg)
{
@@ -61,8 +61,8 @@ typedef struct __mavlink_camera_capture_status_t {
* @param time_boot_ms Timestamp (milliseconds since system boot)
* @param camera_id Camera ID (1 for first, 2 for second, etc.)
- * @param image_status Current status of image capturing (0: not running, 1: interval capture in progress)
- * @param video_status Current status of video capturing (0: not running, 1: capture in progress)
+ * @param image_status Current status of image capturing (0: idle, 1: capture in progress, 2: interval set but idle, 3: interval set and capture in progress)
+ * @param video_status Current status of video capturing (0: idle, 1: capture in progress)
* @param image_interval Image capture interval in seconds
* @param recording_time_ms Time in milliseconds since recording started
@@ -107,8 +107,8 @@ static inline uint16_t mavlink_msg_camera_capture_status_pack(uint8_t system_id,
* @param time_boot_ms Timestamp (milliseconds since system boot)
* @param camera_id Camera ID (1 for first, 2 for second, etc.)
- * @param image_status Current status of image capturing (0: not running, 1: interval capture in progress)
- * @param video_status Current status of video capturing (0: not running, 1: capture in progress)
+ * @param image_status Current status of image capturing (0: idle, 1: capture in progress, 2: interval set but idle, 3: interval set and capture in progress)
+ * @param video_status Current status of video capturing (0: idle, 1: capture in progress)
* @param image_interval Image capture interval in seconds
* @param recording_time_ms Time in milliseconds since recording started
@@ -179,8 +179,8 @@ static inline uint16_t mavlink_msg_camera_capture_status_encode_chan(uint8_t sys
* @param time_boot_ms Timestamp (milliseconds since system boot)
* @param camera_id Camera ID (1 for first, 2 for second, etc.)
- * @param image_status Current status of image capturing (0: not running, 1: interval capture in progress)
- * @param video_status Current status of video capturing (0: not running, 1: capture in progress)
+ * @param image_status Current status of image capturing (0: idle, 1: capture in progress, 2: interval set but idle, 3: interval set and capture in progress)
+ * @param video_status Current status of video capturing (0: idle, 1: capture in progress)
* @param image_interval Image capture interval in seconds
* @param recording_time_ms Time in milliseconds since recording started
@@ -292,7 +292,7 @@ static inline uint8_t mavlink_msg_camera_capture_status_get_camera_id(const mavl
* @brief Get field image_status from camera_capture_status message
*
- * @return Current status of image capturing (0: not running, 1: interval capture in progress)
+ * @return Current status of image capturing (0: idle, 1: capture in progress, 2: interval set but idle, 3: interval set and capture in progress)
*/
static inline uint8_t mavlink_msg_camera_capture_status_get_image_status(const mavlink_message_t* msg)
@@ -302,7 +302,7 @@ static inline uint8_t mavlink_msg_camera_capture_status_get_image_status(const m
* @brief Get field video_status from camera_capture_status message
*
- * @return Current status of video capturing (0: not running, 1: capture in progress)
+ * @return Current status of video capturing (0: idle, 1: capture in progress)
*/
static inline uint8_t mavlink_msg_camera_capture_status_get_video_status(const mavlink_message_t* msg)